#Homevee - Dein neues Smarthome-System

[![Repo on GitHub](https://img.shields.io/badge/repo-GitHub-3D76C2.svg)](https://github.com/homevee/Homevee)
[![Repo on GitLab](https://img.shields.io/badge/repo-GitLab-6C488A.svg)](https://gitlab.com/homevee/Homevee)
[![Repo on BitBucket](https://img.shields.io/badge/repo-BitBucket-1F5081.svg)](https://bitbucket.org/homevee/Homevee)

##Installation:
sudo apt-get install wakeonlan libjpeg-dev mosquitto python3-pip -y
sudo pip3 install Homevee
